@@ -58,6 +58,13 @@ class SwitchGuideDefinitionOptions(BaseModel):
     availableOnMarketplaceForUserType: Optional[MarketplaceUserType]
     """User types the guide is available for on the Marketplace"""
 
+    enablePeriodicStatusCheck: bool = False
+    """Enable automated and periodic status checking for this Guide
+    Some steps in a Guide migth depend on state outside of the scope of the Guide.
+    Examples when step depends on data sources with eventual consistency, action requiring user input, or an approval system etc.
+    With this enabled the check_status method will be called periodically until the guide is completed.
+    """
+
 
 class SwitchGuideSummaryStepEvents(BaseModel):
     """Events that can be triggered on the Summary Step
